@@ -17,8 +17,8 @@ def test_info_url(age_restricted):
         video_id="QRS8MkLhQmM", embed_html=age_restricted["embed_html"],
     )
     expected = (
-        "https://youtube.com/get_video_info?video_id=QRS8MkLhQmM&eurl"
-        "=https%3A%2F%2Fyoutube.googleapis.com%2Fv%2FQRS8MkLhQmM&sts="
+        "https://www.youtube.com/get_video_info?video_id=QRS8MkLhQmM&eurl"
+        "=https%3A%2F%2Fyoutube.googleapis.com%2Fv%2FQRS8MkLhQmM&sts=&html5=1"
     )
     assert video_info_url == expected
 
@@ -29,9 +29,9 @@ def test_info_url_age_restricted(cipher_signature):
         watch_url=cipher_signature.watch_url,
     )
     expected = (
-        "https://youtube.com/get_video_info?video_id=2lAe1cqCOXo"
+        "https://www.youtube.com/get_video_info?video_id=2lAe1cqCOXo"
         "&ps=default&eurl=https%253A%2F%2Fyoutube.com%2Fwatch%253Fv%"
-        "253D2lAe1cqCOXo&hl=en_US"
+        "253D2lAe1cqCOXo&hl=en_US&html5=1"
     )
     assert video_info_url == expected
 
